"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const ng = require("@angular/compiler-cli");
const path = require("path");
const path_1 = require("../util/path");
function cacheCompilerHost(compilerOptions, sourcesFileCache, moduleResolutionCache, stylesheetProcessor) {
    const compilerHost = ng.createCompilerHost({ options: compilerOptions });
    return Object.assign({}, compilerHost, { 
        // ts specific
        fileExists: (fileName) => {
            const cache = sourcesFileCache.getOrCreate(fileName);
            if (cache.exists === undefined) {
                cache.exists = compilerHost.fileExists.call(this, fileName);
            }
            return cache.exists;
        }, getSourceFile: (fileName, languageVersion) => {
            const cache = sourcesFileCache.getOrCreate(fileName);
            if (!cache.sourceFile) {
                cache.sourceFile = compilerHost.getSourceFile.call(this, fileName, languageVersion);
            }
            return cache.sourceFile;
        }, writeFile: (fileName, data, writeByteOrderMark, onError, sourceFiles) => {
            if (fileName.endsWith('.d.ts')) {
                sourceFiles.forEach(source => {
                    const cache = sourcesFileCache.getOrCreate(source.fileName);
                    if (!cache.declarationFileName) {
                        cache.declarationFileName = path_1.ensureUnixPath(fileName);
                    }
                });
            }
            compilerHost.writeFile.call(this, fileName, data, writeByteOrderMark, onError, sourceFiles);
        }, readFile: (fileName) => {
            const cache = sourcesFileCache.getOrCreate(fileName);
            if (cache.content === undefined) {
                cache.content = compilerHost.readFile.call(this, fileName);
            }
            return cache.content;
        }, 
        // ng specific
        moduleNameToFileName: (moduleName, containingFile) => {
            const { resolvedModule } = ts.resolveModuleName(moduleName, path_1.ensureUnixPath(containingFile), compilerOptions, compilerHost, moduleResolutionCache);
            return resolvedModule && resolvedModule.resolvedFileName;
        }, resourceNameToFileName: (resourceName, containingFilePath) => {
            return path.resolve(path.dirname(containingFilePath), resourceName);
        }, readResource: (fileName) => {
            const cache = sourcesFileCache.getOrCreate(fileName);
            if (cache.content === undefined) {
                // todo: transform styles here.
                // the empty string is needed because of include paths file's won't be resolved properly.
                cache.content = compilerHost.readFile.call(this, fileName);
                if (!/(html|htm)$/.test(path.extname(fileName))) {
                    cache.content = stylesheetProcessor.process(fileName, cache.content);
                }
                cache.exists = true;
            }
            return cache.content;
        } });
}
exports.cacheCompilerHost = cacheCompilerHost;
//# sourceMappingURL=cache-compiler-host.js.map